# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

Link para o curso [Python Pro](https://www.python.pro.br/)

[![Build Status](https://app.travis-ci.com/JonathansManoel/libpythonpro.svg?branch=main)](https://app.travis-ci.com/JonathansManoel/libpythonpro)
[![Updates](https://pyup.io/repos/github/JonathansManoel/libpythonpro/shield.svg)](https://pyup.io/repos/github/JonathansManoel/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/JonathansManoel/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/JonathansManoel/libpythonpro/)

Suportada versão 3 de Python

Para instalar:

```console
python3 -m venv .venv
source .venv\Scripts\activate
pip install - r requirements-dev.txt
```
```console
flake8
```

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip
